@@ -228,8 +228,8 @@ class RecordingSource(models.Model):
               sg = SourcesGroup.objects.filter(name=d["sources_group"]["name"])[0]
             except Exception, e:
               sg = SourcesGroup()
+            sg.load_dict(d["sources_group"])
             self.sources_group = sg
-            self.sources_group.load_dict(d["sources_group"])
         elif self.sources_group:
             self.sources_group = None
 
